The changelog is kept as [release notes](https://github.com/smok-serwis/coolamqp/releases/)
on GitHub. This file serves to only note what changes
have been made so far, between releases.

# v1.2.13

** bugfix release ** fixed `LoggingFrameTracer`
